'use strict';

const config = require('../config.js');
const { getMetapakConfig } = require('../utils');

const TEXT_SNIPPET = `# This file is automatically generated by a
# \`metapak\` module. Do NOT change it in
# place, your changes would be overriden.

`;
const HTML_SNIPPET = `<!--
${TEXT_SNIPPET.trim()}
-->

`;
const JS_SNIPPET = TEXT_SNIPPET.replace(/(\n|^)# /g, '\n// ');

module.exports = (file, packageConf) => {
  const { data } = getMetapakConfig(packageConf);

  // Rename dot files the right way
  if (file.name.startsWith('_dot_')) {
    file.name = file.name.replace('_dot_', '.');
  }

  // Add NodeJS LTS where needed
  if (['.github/ISSUE_TEMPLATE.md'].includes(file.name)) {
    file.data = file.data.replace(/<lastNodeLTS>/gm, config.lastNodeLTS);
  }

  // Add files to `.gitignore`
  if (file.name.endsWith('.gitignore') && data.ignore && data.ignore.length) {
    file.data =
      file.data +
      '# Project custom ignored file\n' +
      data.ignore.join('\n') +
      '\n';
  }

  // Empty files are returned as is
  if (file.name !== '' && file.data == '') {
    return file;
  }

  // Add snippets
  if (file.name.endsWith('.md') || file.name.endsWith('.html')) {
    file.data = HTML_SNIPPET + file.data;
  } else if (
    file.name.endsWith('.yml') ||
    file.name.endsWith('.sh') ||
    file.name.endsWith('.txt') ||
    file.name.endsWith('.editorconfig') ||
    file.name.endsWith('.gitattributes') ||
    file.name.endsWith('.gitignore')
  ) {
    file.data = TEXT_SNIPPET + file.data;
  } else if (file.name.endsWith('.js')) {
    file.data = JS_SNIPPET.trimLeft() + file.data;
  }

  return file;
};
